==> icedtea-bin-src-3.2.0.tar.xz: sun/awt/resources/awt_sv.java <==
package sun.awt.resources;

import java.util.ListResourceBundle;

public final class awt_sv extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "AWT.CompositionWindowTitle", "Inmatningsf\u00F6nster" },
            { "AWT.CrosshairCursor", "H\u00E5rkorsmark\u00F6r" },
            { "AWT.DefaultCursor", "Standardmark\u00F6r" },
            { "AWT.DefaultDragCursor", "Standarddragmark\u00F6r" },
            { "AWT.DefaultDropCursor", "Standardsl\u00E4ppmark\u00F6r" },
            { "AWT.DefaultNoDropCursor", "Standardmark\u00F6r (ej drag)" },
            { "AWT.EResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (\u00F6st)" },
            { "AWT.HandCursor", "Handmark\u00F6r" },
            { "AWT.HostInputMethodDisplayName", "Systeminmatningsmetoder" },
            { "AWT.InconsistentDLLsWarning", "Textbaserade \u00E5tg\u00E4rder kanske inte fungerar korrekt p\u00E5 grund av en inkonsekvent upps\u00E4ttning dynamiskt l\u00E4nkade bibliotek (DLL) som \u00E4r installerade i systemet. F\u00F6r mer information om detta problem och en tillf\u00E4llig l\u00F6sning, se Java(TM) 2 SDK, Standard Edition Release Notes p\u00E5 java.sun.com." },
            { "AWT.InputMethodCreationFailed", "Kan inte skapa {0}.  Orsak: {1}" },
            { "AWT.InputMethodLanguage.ja", "Japanska" },
            { "AWT.InputMethodLanguage.ko", "Koreanska" },
            { "AWT.InputMethodLanguage.zh", "Kinesiska" },
            { "AWT.InputMethodLanguage.zh_CN", "F\u00F6renklad kinesiska" },
            { "AWT.InputMethodLanguage.zh_TW", "Traditionell kinesiska" },
            { "AWT.InputMethodSelectionMenu", "V\u00E4lj inmatningsmetod" },
            { "AWT.Less", "Mindre" },
            { "AWT.MoveCursor", "Flyttmark\u00F6r" },
            { "AWT.NEResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (nordost)" },
            { "AWT.NResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (nord)" },
            { "AWT.NWResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (nordv\u00E4st)" },
            { "AWT.SEResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (sydost)" },
            { "AWT.SResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (syd)" },
            { "AWT.SWResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (sydv\u00E4st)" },
            { "AWT.TextCursor", "Textmark\u00F6r" },
            { "AWT.WResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (v\u00E4st)" },
            { "AWT.WaitCursor", "V\u00E4ntemark\u00F6r" },
            { "AWT.accept", "Acceptera" },
            { "AWT.add", "NUM +" },
            { "AWT.again", "Upprepa" },
            { "AWT.allCandidates", "Alla kandidater" },
            { "AWT.alphanumeric", "Alfanumerisk" },
            { "AWT.alt", "Alt" },
            { "AWT.altGraph", "Alt Graph" },
            { "AWT.ampersand", "Et-tecken" },
            { "AWT.asterisk", "Asterisk" },
            { "AWT.at", "Vid" },
            { "AWT.backQuote", "V\u00E4nster citattecken" },
            { "AWT.backSlash", "Omv\u00E4nt snedstreck" },
            { "AWT.backSpace", "Backsteg" },
            { "AWT.begin", "Begin" },
            { "AWT.braceLeft", "V\u00E4nster klammerparentes" },
            { "AWT.braceRight", "H\u00F6ger klammerparentes" },
            { "AWT.cancel", "Avbryt" },
            { "AWT.capsLock", "Caps Lock" },
            { "AWT.circumflex", "Cirkumflex" },
            { "AWT.clear", "Rensa" },
            { "AWT.closeBracket", "Hakparentes" },
            { "AWT.codeInput", "Kodindata" },
            { "AWT.colon", "Kolon" },
            { "AWT.comma", "Kommatecken" },
            { "AWT.compose", "Skriv" },
            { "AWT.context", "Snabbmeny" },
            { "AWT.control", "Ctrl" },
            { "AWT.convert", "Konvertera" },
            { "AWT.copy", "Kopiera" },
            { "AWT.cut", "Klipp ut" },
            { "AWT.deadAboveDot", "Dead Above Dot" },
            { "AWT.deadAboveRing", "Dead Above Ring" },
            { "AWT.deadAcute", "Dead Acute" },
            { "AWT.deadBreve", "Dead Breve" },
            { "AWT.deadCaron", "Dead Caron" },
            { "AWT.deadCedilla", "Dead Cedilla" },
            { "AWT.deadCircumflex", "Dead Circumflex" },
            { "AWT.deadDiaeresis", "Dead Diaeresis" },
            { "AWT.deadDoubleAcute", "Dead Double Acute" },
            { "AWT.deadGrave", "Dead Grave" },
            { "AWT.deadIota", "Dead Iota" },
            { "AWT.deadMacron", "Dead Macron" },
            { "AWT.deadOgonek", "Dead Ogonek" },
            { "AWT.deadSemivoicedSound", "Dead Semivoiced Sound" },
            { "AWT.deadTilde", "Dead Tilde" },
            { "AWT.deadVoicedSound", "Dead Voiced Sound" },
            { "AWT.decimal", "NUM ." },
            { "AWT.delete", "Ta bort" },
            { "AWT.divide", "NUM /" },
            { "AWT.dollar", "Dollar" },
            { "AWT.down", "Nedpil" },
            { "AWT.end", "End" },
            { "AWT.enter", "Enter" },
            { "AWT.equals", "Lika med" },
            { "AWT.escape", "Esc" },
            { "AWT.euro", "Euro" },
            { "AWT.exclamationMark", "Utropstecken" },
            { "AWT.f1", "F1" },
            { "AWT.f10", "F10" },
            { "AWT.f11", "F11" },
            { "AWT.f12", "F12" },
            { "AWT.f13", "F13" },
            { "AWT.f14", "F14" },
            { "AWT.f15", "F15" },
            { "AWT.f16", "F16" },
            { "AWT.f17", "F17" },
            { "AWT.f18", "F18" },
            { "AWT.f19", "F19" },
            { "AWT.f2", "F2" },
            { "AWT.f20", "F20" },
            { "AWT.f21", "F21" },
            { "AWT.f22", "F22" },
            { "AWT.f23", "F23" },
            { "AWT.f24", "F24" },
            { "AWT.f3", "F3" },
            { "AWT.f4", "F4" },
            { "AWT.f5", "F5" },
            { "AWT.f6", "F6" },
            { "AWT.f7", "F7" },
            { "AWT.f8", "F8" },
            { "AWT.f9", "F9" },
            { "AWT.final", "Slutlig" },
            { "AWT.find", "S\u00F6k" },
            { "AWT.fullWidth", "Full bredd" },
            { "AWT.greater", "St\u00F6rre" },
            { "AWT.halfWidth", "Halv bredd" },
            { "AWT.help", "Hj\u00E4lp" },
            { "AWT.hiragana", "Hiragana" },
            { "AWT.home", "Hem" },
            { "AWT.inputMethodOnOff", "Indatametod p\u00E5/av" },
            { "AWT.insert", "Insert" },
            { "AWT.invertedExclamationMark", "Inverterat utropstecken" },
            { "AWT.japaneseHiragana", "Japansk Hiragana" },
            { "AWT.japaneseKatakana", "Japansk Katakana" },
            { "AWT.japaneseRoman", "Japanska-latinska" },
            { "AWT.kana", "Kana" },
            { "AWT.kanaLock", "Kana-l\u00E5s" },
            { "AWT.kanji", "Kanji" },
            { "AWT.katakana", "Katakana" },
            { "AWT.left", "V\u00E4nster" },
            { "AWT.leftParenthesis", "V\u00E4nsterparentes" },
            { "AWT.meta", "Meta" },
            { "AWT.minus", "Minus" },
            { "AWT.modechange", "\u00C4ndring av l\u00E4ge" },
            { "AWT.multiply", "NUM *" },
            { "AWT.noconvert", "Ingen konvertering" },
            { "AWT.numLock", "Num Lock" },
            { "AWT.numberSign", "Nummertecken" },
            { "AWT.numpad", "NumPad" },
            { "AWT.openBracket", "Parentes" },
            { "AWT.paste", "Klistra in" },
            { "AWT.pause", "Paus" },
            { "AWT.period", "Punkt" },
            { "AWT.pgdn", "Sida ned" },
            { "AWT.pgup", "Sida upp" },
            { "AWT.plus", "Plus" },
            { "AWT.previousCandidate", "F\u00F6reg\u00E5ende kandidat" },
            { "AWT.printScreen", "Print Screen" },
            { "AWT.props", "Egenskaper" },
            { "AWT.quote", "Citattecken" },
            { "AWT.quoteDbl", "Dubbelt citattecken" },
            { "AWT.right", "H\u00F6ger" },
            { "AWT.rightParenthesis", "H\u00F6gerparentes" },
            { "AWT.romanCharacters", "Latinska tecken" },
            { "AWT.scrollLock", "Scroll Lock" },
            { "AWT.semicolon", "Semikolon" },
            { "AWT.separater", "NUM ," },
            { "AWT.separator", "NUM ," },
            { "AWT.shift", "Skift" },
            { "AWT.slash", "Snedstreck" },
            { "AWT.space", "Blanksteg" },
            { "AWT.stop", "Stopp" },
            { "AWT.subtract", "NUM -" },
            { "AWT.tab", "Tabb" },
            { "AWT.undefined", "Odefinierad" },
            { "AWT.underscore", "Understreck" },
            { "AWT.undo", "\u00C5ngra" },
            { "AWT.unknown", "Ok\u00E4nd" },
            { "AWT.up", "Upp" },
            { "AWT.windows", "Windows" },
            { "java.awt.def.delay", "30" },
            { "java.awt.im.style", "p\u00E5 st\u00E4llet" },
        };
    }
}

==> icedtea-bin-src-7.2.5.6.tar.xz: sun/awt/resources/awt_sv.java <==
package sun.awt.resources;

import java.util.ListResourceBundle;

public final class awt_sv extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "AWT.CompositionWindowTitle", "Inmatningsf\u00F6nster" },
            { "AWT.CrosshairCursor", "H\u00E5rkorsmark\u00F6r" },
            { "AWT.DefaultCursor", "Standardmark\u00F6r" },
            { "AWT.DefaultDragCursor", "Standarddragmark\u00F6r" },
            { "AWT.DefaultDropCursor", "Standardsl\u00E4ppmark\u00F6r" },
            { "AWT.DefaultNoDropCursor", "Standardmark\u00F6r (ej drag)" },
            { "AWT.EResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (\u00F6st)" },
            { "AWT.HandCursor", "Handmark\u00F6r" },
            { "AWT.HostInputMethodDisplayName", "Systeminmatningsmetoder" },
            { "AWT.InconsistentDLLsWarning", "Textbaserade \u00E5tg\u00E4rder kanske inte fungerar korrekt p\u00E5 grund av en inkonsekvent upps\u00E4ttning dynamiskt l\u00E4nkade bibliotek (DLL) som \u00E4r installerade i systemet. F\u00F6r mer information om detta problem och en tillf\u00E4llig l\u00F6sning, se Java(TM) 2 SDK, Standard Edition Release Notes p\u00E5 java.sun.com." },
            { "AWT.InputMethodCreationFailed", "Kan inte skapa {0}.  Orsak: {1}" },
            { "AWT.InputMethodLanguage.ja", "Japanska" },
            { "AWT.InputMethodLanguage.ko", "Koreanska" },
            { "AWT.InputMethodLanguage.zh", "Kinesiska" },
            { "AWT.InputMethodLanguage.zh_CN", "F\u00F6renklad kinesiska" },
            { "AWT.InputMethodLanguage.zh_TW", "Traditionell kinesiska" },
            { "AWT.InputMethodSelectionMenu", "V\u00E4lj inmatningsmetod" },
            { "AWT.Less", "Mindre" },
            { "AWT.MoveCursor", "Flyttmark\u00F6r" },
            { "AWT.NEResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (nordost)" },
            { "AWT.NResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (nord)" },
            { "AWT.NWResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (nordv\u00E4st)" },
            { "AWT.SEResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (sydost)" },
            { "AWT.SResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (syd)" },
            { "AWT.SWResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (sydv\u00E4st)" },
            { "AWT.TextCursor", "Textmark\u00F6r" },
            { "AWT.WResizeCursor", "Mark\u00F6r f\u00F6r storleks\u00E4ndring (v\u00E4st)" },
            { "AWT.WaitCursor", "V\u00E4ntemark\u00F6r" },
            { "AWT.accept", "Acceptera" },
            { "AWT.add", "NUM +" },
            { "AWT.again", "Upprepa" },
            { "AWT.allCandidates", "Alla kandidater" },
            { "AWT.alphanumeric", "Alfanumerisk" },
            { "AWT.alt", "Alt" },
            { "AWT.altGraph", "Alt Graph" },
            { "AWT.ampersand", "Et-tecken" },
            { "AWT.asterisk", "Asterisk" },
            { "AWT.at", "Vid" },
            { "AWT.backQuote", "V\u00E4nster citattecken" },
            { "AWT.backSlash", "Omv\u00E4nt snedstreck" },
            { "AWT.backSpace", "Backsteg" },
            { "AWT.begin", "Begin" },
            { "AWT.braceLeft", "V\u00E4nster klammerparentes" },
            { "AWT.braceRight", "H\u00F6ger klammerparentes" },
            { "AWT.cancel", "Avbryt" },
            { "AWT.capsLock", "Caps Lock" },
            { "AWT.circumflex", "Cirkumflex" },
            { "AWT.clear", "Rensa" },
            { "AWT.closeBracket", "Hakparentes" },
            { "AWT.codeInput", "Kodindata" },
            { "AWT.colon", "Kolon" },
            { "AWT.comma", "Kommatecken" },
            { "AWT.compose", "Skriv" },
            { "AWT.context", "Snabbmeny" },
            { "AWT.control", "Ctrl" },
            { "AWT.convert", "Konvertera" },
            { "AWT.copy", "Kopiera" },
            { "AWT.cut", "Klipp ut" },
            { "AWT.deadAboveDot", "Dead Above Dot" },
            { "AWT.deadAboveRing", "Dead Above Ring" },
            { "AWT.deadAcute", "Dead Acute" },
            { "AWT.deadBreve", "Dead Breve" },
            { "AWT.deadCaron", "Dead Caron" },
            { "AWT.deadCedilla", "Dead Cedilla" },
            { "AWT.deadCircumflex", "Dead Circumflex" },
            { "AWT.deadDiaeresis", "Dead Diaeresis" },
            { "AWT.deadDoubleAcute", "Dead Double Acute" },
            { "AWT.deadGrave", "Dead Grave" },
            { "AWT.deadIota", "Dead Iota" },
            { "AWT.deadMacron", "Dead Macron" },
            { "AWT.deadOgonek", "Dead Ogonek" },
            { "AWT.deadSemivoicedSound", "Dead Semivoiced Sound" },
            { "AWT.deadTilde", "Dead Tilde" },
            { "AWT.deadVoicedSound", "Dead Voiced Sound" },
            { "AWT.decimal", "NUM ." },
            { "AWT.delete", "Ta bort" },
            { "AWT.divide", "NUM /" },
            { "AWT.dollar", "Dollar" },
            { "AWT.down", "Nedpil" },
            { "AWT.end", "End" },
            { "AWT.enter", "Enter" },
            { "AWT.equals", "Lika med" },
            { "AWT.escape", "Esc" },
            { "AWT.euro", "Euro" },
            { "AWT.exclamationMark", "Utropstecken" },
            { "AWT.f1", "F1" },
            { "AWT.f10", "F10" },
            { "AWT.f11", "F11" },
            { "AWT.f12", "F12" },
            { "AWT.f13", "F13" },
            { "AWT.f14", "F14" },
            { "AWT.f15", "F15" },
            { "AWT.f16", "F16" },
            { "AWT.f17", "F17" },
            { "AWT.f18", "F18" },
            { "AWT.f19", "F19" },
            { "AWT.f2", "F2" },
            { "AWT.f20", "F20" },
            { "AWT.f21", "F21" },
            { "AWT.f22", "F22" },
            { "AWT.f23", "F23" },
            { "AWT.f24", "F24" },
            { "AWT.f3", "F3" },
            { "AWT.f4", "F4" },
            { "AWT.f5", "F5" },
            { "AWT.f6", "F6" },
            { "AWT.f7", "F7" },
            { "AWT.f8", "F8" },
            { "AWT.f9", "F9" },
            { "AWT.final", "Slutgiltig" },
            { "AWT.find", "S\u00F6k" },
            { "AWT.fullWidth", "Full bredd" },
            { "AWT.greater", "St\u00F6rre" },
            { "AWT.halfWidth", "Halv bredd" },
            { "AWT.help", "Hj\u00E4lp" },
            { "AWT.hiragana", "Hiragana" },
            { "AWT.home", "Hem" },
            { "AWT.inputMethodOnOff", "Indatametod p\u00E5/av" },
            { "AWT.insert", "Insert" },
            { "AWT.invertedExclamationMark", "Inverterat utropstecken" },
            { "AWT.japaneseHiragana", "Japansk Hiragana" },
            { "AWT.japaneseKatakana", "Japansk Katakana" },
            { "AWT.japaneseRoman", "Japanska-latinska" },
            { "AWT.kana", "Kana" },
            { "AWT.kanaLock", "Kana-l\u00E5s" },
            { "AWT.kanji", "Kanji" },
            { "AWT.katakana", "Katakana" },
            { "AWT.left", "V\u00E4nsterpil" },
            { "AWT.leftParenthesis", "V\u00E4nsterparentes" },
            { "AWT.meta", "Meta" },
            { "AWT.minus", "Minus" },
            { "AWT.modechange", "\u00C4ndring av l\u00E4ge" },
            { "AWT.multiply", "NUM *" },
            { "AWT.noconvert", "Ingen konvertering" },
            { "AWT.numLock", "Num Lock" },
            { "AWT.numberSign", "Nummertecken" },
            { "AWT.numpad", "NumPad" },
            { "AWT.openBracket", "Parentes" },
            { "AWT.paste", "Klistra in" },
            { "AWT.pause", "Paus" },
            { "AWT.period", "Punkt" },
            { "AWT.pgdn", "Page Down" },
            { "AWT.pgup", "Page Up" },
            { "AWT.plus", "Plus" },
            { "AWT.previousCandidate", "F\u00F6reg\u00E5ende kandidat" },
            { "AWT.printScreen", "Print Screen" },
            { "AWT.props", "Egenskaper" },
            { "AWT.quote", "Citattecken" },
            { "AWT.quoteDbl", "Dubbelt citattecken" },
            { "AWT.right", "H\u00F6gerpil" },
            { "AWT.rightParenthesis", "H\u00F6gerparentes" },
            { "AWT.romanCharacters", "Latinska tecken" },
            { "AWT.scrollLock", "Scroll Lock" },
            { "AWT.semicolon", "Semikolon" },
            { "AWT.separater", "NUM ," },
            { "AWT.separator", "NUM ," },
            { "AWT.shift", "Skift" },
            { "AWT.slash", "Snedstreck" },
            { "AWT.space", "Mellanslag" },
            { "AWT.stop", "Stopp" },
            { "AWT.subtract", "NUM -" },
            { "AWT.tab", "Tabb" },
            { "AWT.undefined", "Odefinierad" },
            { "AWT.underscore", "Understreck" },
            { "AWT.undo", "\u00C5ngra" },
            { "AWT.unknown", "Ok\u00E4nd" },
            { "AWT.up", "Upp" },
            { "AWT.windows", "Windows" },
            { "java.awt.def.delay", "30" },
            { "java.awt.im.style", "p\u00E5 st\u00E4llet" },
        };
    }
}
